@@ -670,7 +670,7 @@ class TextToSpeechClient(metaclass=TextToSpeechClientMeta):
         # Done; return the response.
         return response
 
-    def __enter__(self):
+    def __enter__(self) -> "TextToSpeechClient":
         return self
 
     def __exit__(self, type, value, traceback):
