@@ -557,7 +557,7 @@ class TextToSpeechLongAudioSynthesizeClient(
         # Done; return the response.
         return response
 
-    def __enter__(self):
+    def __enter__(self) -> "TextToSpeechLongAudioSynthesizeClient":
         return self
 
     def __exit__(self, type, value, traceback):
